pub trait TracingRedactedExt {
// Required method
fn tracing_redacted(&self) -> DisplayValue<String>;
}Expand description
Extension trait for logging redacted values as display strings.
This works with any tracing subscriber but the output is a flat string,
not structured data. For structural Debug output, use
TracingRedactedDebugExt. For structured valuable output, see
TracingValuableExt.
Required Methods
Sourcefn tracing_redacted(&self) -> DisplayValue<String>
fn tracing_redacted(&self) -> DisplayValue<String>
Wraps the value for tracing logging as a display value.
The value is redacted and converted to a string representation.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".